.. _dhlab:

dhlab
--------------

.. currentmodule:: dhlab

.. toctree::
   :maxdepth: 2

   subpackages
   classes
   functions


API endpoints
~~~~~~~~~~~~~~

.. currentmodule:: dhlab.constants

.. autodata:: BASE_URL

.. autodata:: NGRAM_API

.. autodata:: GALAXY_API

